cartesian_to_reduced — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# cartesian_to_reduced

static ElectronicBandStructure.cartesian_to_reduced(cartesian, reciprocal_lattice)

  Converts cartesian coordinates to fractional coordinates

  Parameters:

    - cartesian (np.ndarray) – The cartesian coordinates. shape = [N,3]

    - reciprocal_lattice (np.ndarray) – The reciprocal lattice vector matrix. Will have the shape (3, 3), defaults to None

  Returns:

    np.ndarray – The fractional coordinates. shape = [N,3]